@@ -13,14 +13,20 @@ SGE = R6::R6Class("SGE",
 
         submit_jobs = function(...) {
             opts = private$fill_options(...)
-            private$job_id = opts$job_name
+            private$job_name = opts$job_name
             filled = private$fill_template(opts)
 
-            success = system("qsub", input=filled, ignore.stdout=TRUE)
-            if (success != 0) {
+            qsub_stdout  = system2("qsub", input=filled, stdout=TRUE)
+
+            status = attr(qsub_stdout, "status")
+            success = (is.null(status) || (status == 0))
+
+            if (!success) {
                 print(filled)
                 stop("Job submission failed with error code ", success)
             }
+
+            private$set_job_id(qsub_stdout)
         },
 
         finalize = function(quiet=self$workers_running == 0) {
@@ -33,7 +39,12 @@ SGE = R6::R6Class("SGE",
     ),
 
     private = list(
-        job_id = NULL
+        job_name = NULL,
+        job_id   = NULL,
+
+        # This implementation of set_job_id ignores input argument qsub_stdout
+        # as it can use job_name to refer to jobs in qdel
+        set_job_id = function(qsub_stdout) private$job_id = private$job_name
     )
 )
 
@@ -44,11 +55,15 @@ PBS = R6::R6Class("PBS",
         initialize = function(..., template=getOption("clustermq.template", "PBS")) {
             super$initialize(..., template=template)
         }
+    ),
+
+    private = list(
+      set_job_id = function(qsub_stdout) private$job_id = qsub_stdout[1]
     )
 )
 
 TORQUE = R6::R6Class("TORQUE",
-    inherit = SGE,
+    inherit = PBS,
 
     public = list(
         initialize = function(..., template=getOption("clustermq.template", "TORQUE")) {
