@@ -1,5 +1,6 @@
 context("qsys implementations")
 
+has_cmq = has_cmq()
 has_network = has_connectivity(host())
 avail = Sys.which(c("bsub", "qsub", "sbatch", "fake_scheduler.sh"))
 avail = as.list(nchar(avail) != 0)
@@ -29,33 +30,33 @@ test_that("qsys_multicore", {
 })
 
 test_that("qsys_lsf", {
-    skip_if_not_installed('clustermq')
+    skip_on_cran()
     skip_if_not(with(avail, bsub))
+    skip_if_not(has_cmq)
     skip_if_not(has_network)
     skip_on_os("windows")
-    skip_on_cran()
     w = workers(n_jobs=1, qsys_id="lsf", reuse=FALSE)
     r = Q(fx, x=1:3, workers=w, timeout=3L)
     expect_equal(r, as.list(1:3*2))
 })
 
 test_that("qsys_sge", {
-    skip_if_not_installed('clustermq')
+    skip_on_cran()
     skip_if_not(with(avail, qsub))
+    skip_if_not(has_cmq)
     skip_if_not(has_network)
     skip_on_os("windows")
-    skip_on_cran()
     w = workers(n_jobs=1, qsys_id="sge", reuse=FALSE)
     r = Q(fx, x=1:3, workers=w, timeout=3L)
     expect_equal(r, as.list(1:3*2))
 })
 
 test_that("qsys_slurm", {
-    skip_if_not_installed('clustermq')
+    skip_on_cran()
     skip_if_not(with(avail, sbatch))
+    skip_if_not(has_cmq)
     skip_if_not(has_network)
     skip_on_os("windows")
-    skip_on_cran()
     w = workers(n_jobs=1, qsys_id="slurm", reuse=FALSE)
     r = Q(fx, x=1:3, workers=w, timeout=3L)
     expect_equal(r, as.list(1:3*2))
